harness_py_sdk.harness_pipelines API documentation

# harness_py_sdk.harness_pipelines

class HarnessPipelines:
HarnessPipelines(harness_service)
def fetch_pipeline_yaml(self, org_identifier, project_identifier, pipeline_identifier):
def create_pipeline(self, org_identifier, project_identifier, pipeline_data):
def update_pipeline( self, org_identifier, project_identifier, pipeline_data, pipeline_identifier):
def delete_pipeline(self, org_identifier, project_identifier, pipeline_identifier):